@@ -518,7 +518,7 @@ removePrintVersion lem
   = fun
       ["/Druckversion","/ Druckversion","/Print version", "/Complete Wikibook", "/All Chapters",
        "/Print Version", "/print version", "/Printable version",
-       "/The Whole Book", "/print"]
+       "/The Whole Book", "/print", ": Druckversion"]
       lem
   where fun (y : ys) x
           = case splitOn y x of
@@ -537,7 +537,7 @@ goodtags1
      "strike", "object", "input", "center", "legend", "iframe", "small",
      "video", "audio", "style", "input", "label", "tbody", "thead",
      "title", "frame", "param", "base", "area", "font", "code", "span",
-     "abbr", "body", "link", "menu", "meta", "samp", "cite", "head",
+     "abbr", "body", "link", "menu", "math", "meta", "samp", "cite", "head",
      "html", "poem", "form", "cite", "ref", "div", "pre", "sub", "sup",
      "big", "del", "map", "bdo", "var", "dfn", "kbd", "col", "ins",
      "dir", "img", "h1", "h2", "h3", "h4", "h5", "h6", "li", "ul", "ol",
