@@ -42,7 +42,7 @@ data MyState = MyState{getImages :: [String], getJ :: Int,
                        urld :: WikiUrlData, getGalleryNumbers :: [Integer],
                        currentUrl :: String, fndict :: Map String [Anything Char],
                        tablist :: [[String]], tabmap :: Map Int (Map Int Double),
-                       fontStack :: [FontStyle], font :: Font}
+                       fontStack :: [FontStyle], font :: Font, langu:: Maybe String, forms::Map String Int, lastChar::Char, lastFontChanged::Bool}
              deriving (Show, Eq)
  
 {-DHUN| Renderer is the State monad using MyState as mutable state DHUN-}
@@ -62,7 +62,7 @@ initialState
             tabmap = Map.empty,
             fontStack =
               [FontStyle{stylebase = Normal, bold = False, italic = False}],
-            font = ComputerModernRoman}
+            font = ComputerModernRoman, langu=Nothing, forms=Map.empty , lastChar=' ', lastFontChanged=False}
  
 {-DHUN| represents an URL to a wiki (not to a page thereof), which is not a sister project of wikipedia, so not wikibooks wikisource, etc. DHUN-}
  
