@@ -22,7 +22,6 @@ import qualified Data.ByteString as BStr
 import qualified Data.ByteString.UTF8 as UTF8Str
 import qualified Network.HTTP.Types as T
 import qualified Network.HTTP.Types.Version as V
-import Data.Char
 {-DHUN| This represents the main url of a wiki page. So the url of the wiki page that should be converted to latex. It is a tuple wrapped into the maybe monad, to deal with case in which the url could not be parses. The first element of the tuple is just the main url parser with Network.URL The second element is a list of urls. These URLs are possible base urls for wiki pages. So en.wikipedia.org/wiki/Foobar has got the main url en.wikipedia.org/wiki/Foobar and one of the base urls us en.wikipedia.org/wiki/. Base urls are important since the wiki source related to the main url might include subpage in wiki notation that is [[JohnDow]]. The actual url to look up JohnDow is the baseurl plus JohnDow so that is en.wikipedia.org/wiki/JohnDow Since also images in the commons and similar things are possible, the are usually some baseurls to be looked at. This way the base URl have to be a list. DHUN-}
  
 type WikiUrl = Maybe (URL, [URL])
@@ -81,7 +80,8 @@ geturl u
                      (map (\ (a, b) -> (UTF8Str.fromString a, UTF8Str.fromString b))
                         []))
                     req0) {method=method req0}
-          res <- (withManager $ httpLbs req)`X.catch` statusExceptionHandler
+          manager <- newManager tlsManagerSettings
+          res <- (httpLbs req manager)`X.catch` statusExceptionHandler
           return ((unpackChars (responseBody res))))
       fun
  where  
@@ -100,8 +100,9 @@ geturl2 u
                      (map (\ (a, b) -> (UTF8Str.fromString a, UTF8Str.fromString b))
                         []))
                     req0) {method=method req0}
-          res <- (withManager $ httpLbs req)`X.catch` statusExceptionHandler
-          return (BStr.pack (map (fromIntegral.ord)(unpackChars (responseBody res)))))
+          manager <- newManager tlsManagerSettings
+          res <- (httpLbs req manager)`X.catch` statusExceptionHandler
+          return  (L.toStrict (responseBody res)))
       fun
  where  
         fun :: ErrorCall -> IO BStr.ByteString
@@ -119,7 +120,8 @@ geturl4 s u
                      (map (\ (a, b) -> (UTF8Str.fromString a, UTF8Str.fromString b))
                         [("mw-input-pages",s),("curonly","1"),("wpExportTemplates","0"),("wpDownload","1")]))
                     req0) 
-          res <- (withManager (httpLbs req))`X.catch` statusExceptionHandler
+          manager <- newManager tlsManagerSettings
+          res <- (httpLbs req manager)`X.catch` statusExceptionHandler
           return ((unpackChars (responseBody res))))
       fun
  where  
@@ -142,7 +144,8 @@ geturl3 u d s
                         [("wpInput", d), ("removecomments", "1"), ("removenowiki", "1"),
                          ("generate_xml", "0"), ("contexttitle", s)]))
                     req0
-          res <- (withManager $ httpLbs req) `X.catch` statusExceptionHandler
+          manager <- newManager tlsManagerSettings
+          res <- (httpLbs req manager) `X.catch` statusExceptionHandler
           return ((unpackChars (responseBody res))))
       fun
  where  
