@@ -90,6 +90,20 @@ linkLocation l
               (case xx of
                    [] -> ""
                    (g : _) -> g)
+
+
+normalizeExtensionHtml :: String -> String
+normalizeExtensionHtml ('s' : ('v' : ('g' : _))) = "png"
+normalizeExtensionHtml ('j' : ('p' : ('e' : ('g' : _)))) = "jpg"
+normalizeExtensionHtml ('j' : ('p' : ('g' : _))) = "jpg"
+normalizeExtensionHtml ('g' : ('i' : ('f' : _))) = "gif"
+normalizeExtensionHtml ('p' : ('n' : ('g' : _))) = "png"
+normalizeExtensionHtml ('t' : ('i' : ('f' : ('f' : _)))) = "png"
+normalizeExtensionHtml ('t' : ('i' : ('f' : _))) = "png"
+normalizeExtensionHtml (' ' : xs) = normalizeExtension xs
+normalizeExtensionHtml (x : xs) = x : (normalizeExtension xs)
+normalizeExtensionHtml [] = []
+
  
 {-DHUN| changes the extension for a filename given in the wiki source to the extension to be used in the latex document. For example gif documents are converted to png documents. So this function converts the string 'gif' to the string 'png' DHUN-}
  
@@ -194,7 +208,7 @@ mathTransform x
  
 replist :: [([Char], [Char])]
 replist
-  = [("\\or", "\\vee{}"), ("%", "\\%"), ("\\and", "\\wegde"),
+  = [("\\or", "\\vee{}"), ("%", "\\%"), ("\\and", "\\wedge{}"),
      ("\\begin{align}", "\\begin{aligned}"),
      ("\\end{align}", "\\end{aligned}"), ("\\\\%", "\\%"),
      ("\\part ", "\\partial "), ("\\part{", "\\partial{"), ("\\;", ""),
