@@ -2,7 +2,7 @@
 module Main where
 import All
 import Control.Monad.State
-import Control.Monad.Error
+import Control.Monad.Except
 import System.Directory
 import System.Environment
 import System.Console.GetOpt
@@ -174,7 +174,7 @@ header = "Usage: mediawiki2latex [OPTION...]"
  
 versionHeader :: String
 versionHeader
-  = "mediawiki2latex version 7.22\n" ++ (usageInfo header options)
+  = "mediawiki2latex version 7.23\n" ++ (usageInfo header options)
  
 {-DHUN| print the version string of mediawiki2latex. Takes the output of the compilerOpts function as input. Prints the version string if no options were given or the version command was given does noting otherwise DHUN-}
  
@@ -377,7 +377,7 @@ main
                        Just (s,e)->runSelfTest s e
                        _-> case (server x) of
                             Just zz -> serve zz
-                            _ -> do (xx, _) <- (runStateT (runErrorT (All.all x))
+                            _ -> do (xx, _) <- (runStateT (runExceptT (All.all x))
                                                 stz)
                                     case xx of
                                       Left n -> print n
